package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jan 3, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
brwsr

brwsr provides a way to open URL links in the user's default browser, compatible with most operating systems.
Example
package main
import "github.com/speedyhoon/brwsr"
func main() {
// Open locally hosted Godoc.
err := brwsr.Open("https://localhost:6060")
if err != nil {
println(err)
}
}
Documentation
¶
Package brwsr implements a way to open URL links in the user's default browser, compatible with most operating systems.
ErrOpen is unable to open the default web browser for a URL.
Open a URL link in the user's default browser.
package main
import (
"github.com/speedyhoon/brwsr"
)
func main() {
// Open locally hosted Godoc.
err := brwsr.Open("https://localhost:6060")
if err != nil {
println(err)
}
}
Output:
Source Files
¶
Click to show internal directories.
Click to hide internal directories.